@@ -25,7 +25,7 @@ namespace cln {
 #if defined(__i386__) || defined(__mips__) || defined(__sparc__) || defined(__hppa__) || defined(__arm__) || defined(__rs6000__) || defined(__m88k__) || defined(__convex__) || defined(__s390__)
   #define cl_word_alignment  4
 #endif
-#if defined(__alpha__) || defined(__mips64__) || defined(__sparc64__) || defined(__ia64__)
+#if defined(__alpha__) || defined(__mips64__) || defined(__sparc64__) || defined(__ia64__) || defined(__x86_64__)
   #define cl_word_alignment  8
 #endif
 #if !defined(cl_word_alignment)
@@ -243,7 +243,7 @@ inline _class_::_classname_ (const _class_& x)			\
 {								\
 	cl_uint x_word = x.word;				\
 	cl_inc_refcount(x);					\
-	word = x_word;						\
+	this->word = x_word;					\
 }
 
 // The declaration of a copy constructor.
@@ -263,7 +263,7 @@ inline dest_class& dest_class::operator= (const src_class& x)	\
 	cl_uint x_word = x.word;				\
 	cl_inc_refcount(x);					\
 	cl_dec_refcount(*this);					\
-	word = x_word;						\
+	this->word = x_word;					\
 	return *this;						\
 }
 
