@@ -12,7 +12,7 @@
 #include "cl_base_config.h"
 #include "cl_low.h"
 
-#if defined(unix) || defined(__unix) || defined(_AIX) || defined(sinix) || (defined(_WIN32) && defined(__GNUC__)) || defined(__BEOS__)
+#if defined(unix) || defined(__unix) || defined(_AIX) || defined(sinix) || (defined(__MACH__) && defined(__APPLE__)) || (defined(_WIN32) && defined(__GNUC__)) || defined(__BEOS__)
 
 #include <sys/types.h>
 #include <unistd.h> // declares getpid()
@@ -34,22 +34,6 @@ inline uint32 get_seed (void)
 	return cln::highlow32(tv.tv_sec,tv.tv_usec); // 16+16 zufllige Bits
 }
 
-#elif defined(HAVE_FTIME)
-
-#include <sys/timeb.h>
-#ifdef _WIN32
-  extern "C" void ftime (struct timeb * tp);
-#else
-  extern "C" int ftime (struct timeb * tp);
-#endif
-
-inline uint32 get_seed (void)
-{
-	var struct timeb tb;
-	ftime(&tb);
-	return (tb.time << 10) | tb.millitm; // 22+10 zufllige Bits
-}
-
 #elif defined(HAVE_TIMES_CLOCK)
 
 #include <time.h>
@@ -80,7 +64,7 @@ random_state::random_state ()
 {
 	var uint32 seed_hi;
 	var uint32 seed_lo;
-#if defined(unix) || defined(__unix) || defined(_AIX) || defined(sinix) || (defined(_WIN32) && defined(__GNUC__)) || defined(__BEOS__)
+#if defined(unix) || defined(__unix) || defined(_AIX) || defined(sinix) || (defined(__MACH__) && defined(__APPLE__)) || (defined(_WIN32) && defined(__GNUC__)) || defined(__BEOS__)
 	seed_lo = ::get_seed();
 	seed_hi = (rand() // zufllige 31 Bit (bei UNIX_BSD) bzw. 16 Bit (bei UNIX_SYSV)
                           << 8) ^ (uintL)(getpid()); // ca. 8 Bit von der Process ID
