@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_string.h"
+#include "cln/string.h"
 
 
 // Implementation.
@@ -13,6 +13,8 @@
 #define MAYBE_INLINE inline
 #include "cl_st_make0.cc"
 
+namespace cln {
+
 const cl_string operator+ (const cl_string& str1, const cl_string& str2)
 {
     unsigned long len1 = strlen(str1);
@@ -32,3 +34,5 @@ const cl_string operator+ (const cl_string& str1, const cl_string& str2)
     *ptr++ = '\0';
     return str;
 }
+
+}  // namespace cln
