@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
 
+namespace cln {
+
 static void complex_destructor (cl_heap* pointer)
 {
 	(*(cl_heap_complex*)pointer).~cl_heap_complex();
@@ -20,3 +22,5 @@ cl_class cl_class_complex = {
 	complex_destructor,
 	cl_class_flags_subclass_complex
 };
+
+}  // namespace cln
