@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
-#include "cl_real.h"
+#include "cln/real.h"
+
+namespace cln {
 
 const cl_N tanh (const cl_N& x)
 {
@@ -20,15 +22,15 @@ const cl_N tanh (const cl_N& x)
 //                (complex (* (cosh a) (cos b)) (* (sinh a) (sin b))) )
 	if (realp(x)) {
 		DeclareType(cl_R,x);
-		var cl_cosh_sinh_t hyp = cl_cosh_sinh(x);
+		var cosh_sinh_t hyp = cosh_sinh(x);
 		return hyp.sinh / hyp.cosh;
 	} else {
 		DeclareType(cl_C,x);
 		// x=a+bi
 		var const cl_R& a = realpart(x);
 		var const cl_R& b = imagpart(x);
-		var cl_cos_sin_t trig_b = cl_cos_sin(b); // cos(b), sin(b) errechnen
-		var cl_cosh_sinh_t hyp_a = cl_cosh_sinh(a); // cosh(a), sinh(a) errechnen
+		var cos_sin_t trig_b = cos_sin(b); // cos(b), sin(b) errechnen
+		var cosh_sinh_t hyp_a = cosh_sinh(a); // cosh(a), sinh(a) errechnen
 		return
 			complex_C(hyp_a.sinh * trig_b.cos, // sinh(a)*cos(b)
 				  hyp_a.cosh * trig_b.sin // cosh(a)*sin(b), nicht Fixnum 0
@@ -38,3 +40,5 @@ const cl_N tanh (const cl_N& x)
 			       );
 	}
 }
+
+}  // namespace cln
