@@ -4,12 +4,16 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_dfloat.h"
+#include "cln/dfloat.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_DF min (const cl_DF& x, const cl_DF& y)
 {
 	return (x <= y ? x : y);
 }
+
+}  // namespace cln
