@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer_io.h"
+#include "cln/integer_io.h"
 
 
 // Implementation.
@@ -13,6 +13,8 @@
 #include "cl_DS.h"
 #include "cl_sstring.h"
 
+namespace cln {
+
 char * cl_decimal_string (const cl_I& x)
 {
 	CL_ALLOCA_STACK;
@@ -23,3 +25,5 @@ char * cl_decimal_string (const cl_I& x)
 	var char* result = cl_sstring((char*)erg.MSBptr,erg.len); // Ziffern in String schreiben
 	return result;
 }
+
+}  // namespace cln
